
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2018 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_PITCHPICKERDIALOG_H
#define RG_PITCHPICKERDIALOG_H

#include "gui/widgets/PitchChooser.h"
#include <QDialog>


class QWidget;


namespace Rosegarden
{

/*
 * Creates a small dialog box containing a PitchChooser widget.  The
 * info paramter provides extra information as a reminder what this particular
 * picker is for, eg. Highest, Lowest, From, To
 */

class PitchPickerDialog : public QDialog
{
    Q_OBJECT

public:

    PitchPickerDialog(QWidget* parent, int initialPitch, QString text);
    ~PitchPickerDialog() override;

    int getPitch() { return m_pitch->getPitch(); }
    
private:
    PitchChooser* m_pitch;
};


}

#endif
